.. contents::

Welcome to the Python for Process Engineering Schema (PyPES) documentation!
===========================================================================

.. toctree::
   :maxdepth: 1
   :caption: Overview

   README <self>
   hello
   json_rep
   advanced
   CONTRIBUTING
   LICENSE

.. toctree::
   :maxdepth: 1
   :caption: Class Hierarchy

   connection
   node
   tag

.. toctree::
   :maxdepth: 1
   :caption: JSON Parsing

   parse_json
   units

.. toctree::
   :maxdepth: 1
   :caption: Miscellaneous

   operations
   utils
   visualize

.. include:: ../README.rst

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
